<?php
/**
 * Plugin Name: ForeThemes Functions
 * Description: This plugin adds some widgets, share buttons and functions to ForeThemes's themes.
 * Version: 1.0.0
 * Author: ForeThemes
 * Author URI: http://harold.forethemes.com/
 * License: GPL2
 * Text Domain: forethemes
 */

define( 'FORETHEMES_PLUGIN_DIR', untrailingslashit( plugin_dir_path( __FILE__ ) ) );
define( 'FORETHEMES_PLUGIN_URL', untrailingslashit( plugin_dir_url( __FILE__ ) ) );

/**
 * Add Next Page/Page Break Button in WordPress Visual Editor
 */
function forethemes_add_next_page_button( $buttons, $id ){
 
    /* only add this for content editor */
    if ( 'content' != $id )
        return $buttons;
 
    /* add next page after more tag button */
    array_splice( $buttons, 13, 0, 'wp_page' );
 
    return $buttons;
}
/* Add Next Page Button in First Row */
add_filter( 'mce_buttons', 'forethemes_add_next_page_button', 1, 2 ); // 1st row

/**
 * Remove frameborder attribute to match W3C standards
 */
function forethemes_oembed_filter( $return, $data, $url ) {
 	$return = str_replace('frameborder="0"', 'style="border: none"', $return);
 	$return = str_replace('gesture="media"', '', $return);
 	$return = str_replace('allow="encrypted-media"', '', $return);
	return $return;
}
add_filter('oembed_dataparse', 'forethemes_oembed_filter', 90, 3 );

/**
 * Social network sharing button
 */
function forethemes_social_share_wrapper( $post_id ){
	?>
	<ul class="social-sharing-ul">

		<?php if(get_theme_mod('facebook_share_button', true)): ?>
		<li><a href="https://www.facebook.com/sharer/sharer.php?u=<?php echo get_permalink(); ?>"><i class="ion-social-facebook"></i></a></li>
		<?php endif;?>

		<?php if(get_theme_mod('twitter_share_button', true)): ?>
		<li><a href="https://twitter.com/intent/tweet?original_referer=<?php echo get_permalink(); ?>&amp;url=<?php echo get_permalink(); ?>"><i class="ion-social-twitter"></i></a></li>
		<?php endif;?>

		<?php if(get_theme_mod('google_plus_share_button', true)): ?>
		<li><a href="https://plus.google.com/share?url=<?php echo get_permalink();?>" onclick="javascript:window.open(this.href,
'', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;"><i class="ion-social-googleplus-outline"></i></a></li>
		<?php endif;?>

		<?php if(get_theme_mod('pinterest_share_button', true)): ?>
		<li><a href="http://pinterest.com/pin/create/button/?url=<?php echo urlencode(get_permalink()); ?>&amp;media=<?php echo urlencode(wp_get_attachment_url( get_post_thumbnail_id( $post_id ) )); ?>"><i class="ion-social-pinterest"></i></a></li>
		<?php endif;?>

		<?php if(get_theme_mod('linkedin_share_button', false)): ?>
		<li><a href="http://www.linkedin.com/shareArticle?mini=true&amp;url=<?php echo get_permalink(); ?>"><i class="ion-social-linkedin"></i></a></li>
		<?php endif;?>

		<?php if(get_theme_mod('tumblr_share_button', false)): ?>
		<li><a href="http://www.tumblr.com/share/link?url=<?php echo get_permalink(); ?>"><i class="ion-social-tumblr"></i></a></li>
		<?php endif;?>

		<?php if(get_theme_mod('reddit_share_button', false)): ?>
		<li><a href="http://reddit.com/submit?url=<?php echo get_permalink();?>&amp;title=<?php echo get_the_title();?>"><i class="ion-social-reddit"></i></a></li>
		<?php endif;?>

	</ul>
	<?php
}
add_action('forethemes_social_share', 'forethemes_social_share_wrapper', 10, 1);


/**
 * Register widget area.
 */
function forethemes_widgets_init() {
	//About Me Widget
	register_widget( 'Forethemes_About_Me_Widget' );

	//Featured Post Widget
	register_widget( 'Forethemes_Featured_Post_Widget' );

	//Post Widget
	register_widget( 'Forethemes_Post_Widget' );
}
add_action( 'widgets_init', 'forethemes_widgets_init' );

/**
 * Set or Update number of post views
 */
function forethemes_set_post_views($postID) {
	$count_key = 'forethemes_post_view_count';
	$count = get_post_meta($postID, $count_key, true);
	if ( $count == '') {
		$count = 0;
		delete_post_meta($postID, $count_key);
		add_post_meta($postID, $count_key, '0');
	} else {
		$count++;
		update_post_meta($postID, $count_key, $count);
	}
}

/**
 * Get number of post views
 */
function forethemes_get_post_views($postID){
	$count_key = 'forethemes_post_view_count';
	$count = get_post_meta($postID, $count_key, true);
	if ( $count == '' ) {
		delete_post_meta($postID, $count_key);
		add_post_meta($postID, $count_key, '0');
		return "0";
	}
	return $count;
}

require_once( FORETHEMES_PLUGIN_DIR . '/gallery-post/gallery-post-type.php' );

/**
 * Load About Me Widget
 */
require_once( FORETHEMES_PLUGIN_DIR . '/widgets/forethemes-about-me-widget.php' );

/**
 * Load Post Widget
 */
require_once( FORETHEMES_PLUGIN_DIR . '/widgets/forethemes-custom-post-widget.php' );

/**
 * Load Featured Post Widget
 */
require_once( FORETHEMES_PLUGIN_DIR . '/widgets/forethemes-featured-post-widget.php' );