<?php

function forethemes_admin_scripts() {
    wp_register_script('forethemes-gallery-upload', FORETHEMES_PLUGIN_URL .'/gallery-post/js/upload-button.js', array('jquery','media-upload','thickbox'));
    wp_enqueue_script('forethemes-gallery-upload');
    wp_register_style('forethemes-gallery-upload-style', FORETHEMES_PLUGIN_URL . '/gallery-post/css/upload-section.css', array(), '1.0', false);
    wp_enqueue_style('forethemes-gallery-upload-style');
}

add_action('admin_print_scripts', 'forethemes_admin_scripts');

/**
 * Add Featured Media Meta Box
 */
function forethemes_featured_media_link() {
  add_meta_box(
    'forethemes-featured-media-link',      
    esc_html__( 'Post Options', 'forethemes' ),
    'forethemes_featured_media_link_display_box',
    'post',
    'normal',
    'high'
  );
}
add_action( 'add_meta_boxes', 'forethemes_featured_media_link' );


/**
 * Display Featured Media Meta Box
 */
function forethemes_featured_media_link_display_box($post) { 
	$forethemes_link_url = get_post_meta($post->ID, 'forethemes_link_url', true);
	$forethemes_video_url = get_post_meta($post->ID, 'forethemes_video_url', true);
	$forethemes_audio_url = get_post_meta($post->ID, 'forethemes_audio_url', true);
	$forethemes_gallery_display_as = get_post_meta($post->ID, 'forethemes_gallery_display_as', true);
	$forethemes_gallery_image_list = get_post_meta($post->ID, 'forethemes_gallery_image_list', true);
	?>
	<!-- Gallery -->
	<div class="gallery-field">
	<?php forethemes_gallery_upload_form(true, $forethemes_gallery_image_list); ?>
	<div>
	    <label class="form-label">
	        <b><?php _e('Display as', 'forethemes'); ?></b>
	    </label>

	    <select name="forethemes-gallery-display-as">
	        <option value="big_slideshow" <?php if( $forethemes_gallery_display_as == 'big_slideshow' ) echo esc_attr('selected');?>><?php _e("Big Slideshow", "forethemes") ?></option>
	        <option value="small_slideshow" <?php if( $forethemes_gallery_display_as == 'small_slideshow' ) echo esc_attr('selected');?>><?php _e("Small Slideshow", "forethemes") ?></option>
	        <option value="tiled_gallery" <?php if( $forethemes_gallery_display_as == 'tiled_gallery' ) echo esc_attr('selected');?>><?php _e("Tiled Gallery", "forethemes") ?></option>
	    </select>
	</div>
	</div>

	<!-- Link -->
	<div class="link-url-field"><p>
    <label><?php _e( 'Link URL', 'forethemes' ); ?></label>
    <br />
    <input class="featured-link" type="text" name="forethemes-link-url" id="forethemes-link-url" value="<?php echo esc_attr($forethemes_link_url); ?>" />
  	</p></div>

  	<!-- Video -->
  	<div class="video-url-field"><p>
    <label><?php _e( 'Video URL', 'forethemes' ); ?></label>
    <br />
    <input class="featured-link" type="text" name="forethemes-video-url" id="forethemes-video-url" value="<?php echo esc_attr($forethemes_video_url); ?>" />
  	</p></div>

  	<!-- Audio -->
  	<div class="audio-url-field"><p>
    <label><?php _e( 'Audio URL', 'forethemes' ); ?></label>
    <br />
    <input class="featured-link" type="text" name="forethemes-audio-url" id="forethemes-audio-url" value="<?php echo esc_attr($forethemes_audio_url); ?>" />
  	</p></div>
  	<p class="no-url"><?php _e('There is no URL option for this post type', 'forethemes');?></p>
  	<?php
}

/**
 * Upload Form
 */
function forethemes_gallery_upload_form($multiple=false, $value="", $buttonId="")
{
    $buttonId = $buttonId ? $buttonId : uniqid("forethemes-upload-button");
    $url = "";
    if ( $multiple )
    {
        $type   =  'forethemes-multiple-upload';
        $ids    = $value;
        $value  =  explode(",", $value);
        foreach ( $value as $key  )
        {
            $url .= wp_get_attachment_url($key) . ",";
        }
        $url   = rtrim($url, ",");
    }else{
        $type  =  'forethemes-single-upload';
    }

?>
    <div class="<?php echo esc_attr($type); ?>">
        <?php if ( !$multiple ) : ?>
        <input class="forethemes-list-image" type="hidden" value="<?php echo !empty($value) ? esc_url($value) : ''; ?>" name="forethemes-gallery-image-list">
        <input class="forethemes-list-id" type="hidden" value="" name="">
        <?php else : ?>
        <input class="forethemes-list-image" type="hidden" value="<?php echo esc_attr($url); ?>" name="">
        <input class="forethemes-list-id" type="hidden" value="<?php echo esc_attr($ids); ?>" name="forethemes-gallery-image-list">
        <?php endif; ?>
        <button id="<?php echo esc_attr($buttonId); ?>" type="button" class="button button-primary forethemes-btn-upload" value="<?php _e('Upload', 'forethemes'); ?>"><?php _e("Upload", "forethemes") ?></button>
        <ul class="forethemes-wrap-image forethemes-show-image">
            <?php
                if( !empty($value) )
                {
                    if ( $multiple )
                    {
                        foreach ( $value as $id )
                        {
                        	if (wp_get_attachment_image($id, array(75, 75))) 
                            echo '<li class="forethemes-item-image">'.wp_get_attachment_image($id, array(75, 75)).'<div class="forethemes-media-controls"><span class="forethemes-media-edit dashicons dashicons-edit"></span><span class="forethemes-media-remove dashicons dashicons-no-alt"></span></div></li>';
                        }
                    } else {
                        echo '<li class="forethemes-item-image"><img src="'.esc_url($value).'" alt=""><div class="forethemes-media-controls"><span class="forethemes-media-edit dashicons dashicons-edit"></span><span class="forethemes-media-remove dashicons dashicons-no-alt"></span></div></li>';
                    }
                }
            ?>
        </ul>
    </div>
<?php
}

/**
 * Update Featured Media Meta Box
 */
function forethemes_featured_media_link_save($post_id) {
	if( isset( $_POST["forethemes-link-url"]) ) {
		update_post_meta( $post_id, "forethemes_link_url", $_POST["forethemes-link-url"] );
	}
	if( isset( $_POST["forethemes-video-url"]) ) {
		update_post_meta( $post_id, "forethemes_video_url", $_POST["forethemes-video-url"] );
	}
	if( isset( $_POST["forethemes-audio-url"]) ) {
		update_post_meta( $post_id, "forethemes_audio_url", $_POST["forethemes-audio-url"] );
	}
	if( isset( $_POST["forethemes-gallery-display-as"]) ) {
		update_post_meta( $post_id, "forethemes_gallery_display_as", $_POST["forethemes-gallery-display-as"] );
	}
	if( isset( $_POST["forethemes-gallery-image-list"]) ) {
		update_post_meta( $post_id, "forethemes_gallery_image_list", $_POST["forethemes-gallery-image-list"] );
	}
}
add_action('save_post', 'forethemes_featured_media_link_save');

