<?php

function forethemes_widget_enqueue_admin_scripts() {
	$screen = get_current_screen();

	if ( 'widgets' == $screen->id ) {
		wp_register_style( 'forethemes-widgets-style', FORETHEMES_PLUGIN_URL . '/widgets/css/admin.css', array(), false, 'all' );
		wp_enqueue_style( 'forethemes-widgets-style' );

		wp_enqueue_media();
		wp_register_script( 'forethemes-widgets-admin-js', FORETHEMES_PLUGIN_URL . '/widgets/js/admin.js', array ( 'jquery' ), false, true );
		wp_enqueue_script( 'forethemes-widgets-admin-js' );
	}
}
add_action('admin_enqueue_scripts', 'forethemes_widget_enqueue_admin_scripts' );


class Forethemes_About_Me_Widget extends WP_Widget {
	function __construct() {
		$widget_ops = array( 
			'classname' => 'forethemes_about_me_widget',
			'description' => esc_html__('Show some information about yourself.', 'forethemes')
			 );
		parent::__construct( 'forethemes_about_me', esc_html__('Forethemes - About Me', 'forethemes'), $widget_ops );
	}

	function widget($args, $instance) {

		//Get current theme name
		$current_theme = wp_get_theme();

		$instance['title'] = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );

		echo $args['before_widget'];

		if ( !empty($instance['title']) )
			echo $args['before_title'] . $instance['title'] . $args['after_title'];

		$class = !empty( $instance['style'] ) ? $instance['style'] : 'none';

		$style = array();
		if ( 'circle' == $class ) 
		{
			$style[] = 'border-radius:50%';
		}


		$url = !empty( $instance['url'] ) ? esc_url( $instance['url'] ) : '';
		$image = $instance['image'];

		echo '<div class="clearfix">';

		if ( ! empty( $image ) ) 
		{
			if ( !empty( $url ) )
				echo '<a class="image-hover" href="'.$url.'">';

			echo '<img class="img-'.$class.' author-image" alt="Author image" src="'.$image.'" style="'.implode( ';', $style ).'" />';

			if ( !empty( $url ) )
				echo '</a>';
		}

		$allowed_html = array(
			'a' => array(
				'href' => array(),
				'title' => array(),
				'target' => array(),
			),
			'br' => array(),
			'em' => array(),
			'strong' => array(),
		);


		if ( !empty( $instance['description'] ) )
			echo '<p class="sidebar-caption">'.wp_kses( $instance['description'], $allowed_html ).'</p>';

		if ( !empty( $instance['signature'] ) )
			echo '<img class="signature" alt="signature" src="'. $instance['signature'] .'" />';

		echo $args['after_widget'];

		echo '</div>';
	}

	function update( $new_instance, $old_instance ) {
		$instance['title'] = strip_tags( stripslashes($new_instance['title']) );
		$instance['image'] = esc_url_raw( $new_instance['image'] );
		$instance['signature'] = esc_url_raw( $new_instance['signature'] );
		$instance['description'] = stripslashes( $new_instance['description'] );
		$instance['style'] = strip_tags( $new_instance['style'] );
		$instance['url'] = esc_url_raw( $new_instance['url'] );

		return $instance;
	}

	function form( $instance ) {
		$title = isset( $instance['title'] ) ? $instance['title'] : 'About Me!';
		$image = isset( $instance['image'] ) ? $instance['image'] : '';
		$imagestyle = '';
		if ( empty( $image ) )
			$imagestyle = ' style="display:none"';

		$style = isset( $instance['style'] ) ? $instance['style'] : 'none';
		$description = isset( $instance['description'] ) ? $instance['description'] : '';
		$description = esc_textarea($description);
		$url = isset( $instance['url'] ) ? $instance['url'] : '';

		$signature = isset( $instance['signature'] ) ? $instance['signature'] : '';
		?>
		<p>
			<label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:', 'forethemes') ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" value="<?php echo $title; ?>" />
		</p>

		<!-- Choose an avatar -->
		<div class="forethemes-widgets-image-field">
			<input class="widefat" id="<?php echo $this->get_field_id( 'image' ); ?>" name="<?php echo $this->get_field_name( 'image' ); ?>" type="hidden" value="<?php echo $image; ?>" />

			<a class="forethemes-widgets-image-upload button inline-button" data-target="#<?php echo $this->get_field_id( 'image' ); ?>" data-preview=".forethemes-widgets-preview-image" data-frame="select" data-state="forethemes_widgets_insert_single" data-fetch="url" data-title="Insert Image" data-button="Insert" data-class="media-frame forethemes-widgets-custom-uploader" title="Choose An Image">Choose An Image</a>

			<a class="button forethemes-widgets-delete-image" data-target="#<?php echo $this->get_field_id( 'image' ); ?>" data-preview=".forethemes-widgets-preview-image">Delete</a>

			<div class="forethemes-widgets-preview-image"<?php echo $imagestyle; ?>>
				<img src="<?php echo esc_attr($image); ?>" />
			</div>
		</div>

		<!-- Select image style -->
		<p>
			<label for="<?php echo $this->get_field_id('style'); ?>"><?php _e('Image Style:', 'forethemes'); ?></label>
			<select id="<?php echo $this->get_field_id('style'); ?>" name="<?php echo $this->get_field_name('style'); ?>">
				<option value="none"<?php selected( $style, 'none' ); ?>>None</option>';
				<option value="circle"<?php selected( $style, 'circle' ); ?>>Round</option>';
			</select>
		</p>

		<!-- URL -->
		<p>
			<label for="<?php echo $this->get_field_id('url'); ?>"><?php _e('URL:', 'forethemes') ?></label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id('url'); ?>" name="<?php echo $this->get_field_name('url'); ?>" value="<?php echo $url; ?>" />
		</p>

		<!-- Description -->
		<p>
			<label for="<?php echo $this->get_field_id('description'); ?>"><?php _e('Description:', 'forethemes') ?></label>
			<textarea class="widefat" rows="4" cols="20" id="<?php echo $this->get_field_id('description'); ?>" name="<?php echo $this->get_field_name('description'); ?>"><?php echo $description; ?></textarea>
		</p>
		

		<!-- Choose a signature -->
		<div class="forethemes-widgets-image-field">
			<input class="widefat" id="<?php echo $this->get_field_id( 'signature' ); ?>" name="<?php echo $this->get_field_name( 'signature' ); ?>" type="hidden" value="<?php echo $signature; ?>" />
			
			<a class="forethemes-widgets-image-upload button inline-button" data-target="#<?php echo $this->get_field_id( 'signature' ); ?>" data-preview=".forethemes-widgets-preview-image" data-frame="select" data-state="forethemes_widgets_insert_single" data-fetch="url" data-title="Insert Image" data-button="Insert" data-class="media-frame forethemes-widgets-custom-uploader" title="Choose A Signature">Choose A Signature</a>

			<a class="button forethemes-widgets-delete-image" data-target="#<?php echo $this->get_field_id( 'signature' ); ?>" data-preview=".forethemes-widgets-preview-image">Delete</a>

			<?php if ($signature) :?>
				<div class="forethemes-widgets-preview-image">
					<img src="<?php echo esc_attr($signature); ?>" />
				</div>
			<?php endif;?>
			
		</div>
		<?php
	}
}
