<?php
/**
 * Featured Post Widget 
 */
class Forethemes_Featured_Post_Widget extends WP_Widget {

	/**
	 * Sets up a new Recent Posts widget instance.
	 *
	 * @since 2.8.0
	 * @access public
	 */
	public function __construct() {
		$widget_ops = array('classname' => 'forethemes_featured_posts', 'description' => esc_html__( "Display some featured posts. Specially made for Featured Posts section.", 'forethemes') );
		parent::__construct('forethemes-featured-posts', esc_html__('Forethemes - Featured Posts', 'forethemes'), $widget_ops);
	}

	/**
	 * Outputs the content for the current Recent Posts widget instance.
	 *
	 * @since 2.8.0
	 * @access public
	 *
	 * @param array $args     Display arguments including 'before_title', 'after_title',
	 *                        'before_widget', and 'after_widget'.
	 * @param array $instance Settings for the current Featured Posts widget instance.
	 */
	public function widget( $args, $instance ) {
		if ( ! isset( $args['widget_id'] ) ) {
			$args['widget_id'] = $this->id;
		}

		$number = ( ! empty( $instance['number'] ) ) ? absint( $instance['number'] ) : 5;
		if ( ! $number )
			$number = 5;
		$show_date = isset( $instance['show_date'] ) ? $instance['show_date'] : false;

		$orderby 		= 	isset( $instance['orderby'] ) 			? esc_attr( $instance['orderby'] ) 			: 'date';
		$order 			= 	isset( $instance['order'] ) 			? esc_attr( $instance['order'] ) 			: 'desc';
		$category_name 	= 	isset( $instance['category_name'] ) 	? esc_attr( $instance['category_name'] ) 	: 'all';


		/**
		 * Filter the arguments for the Recent Posts widget.
		 *
		 * @since 3.4.0
		 *
		 * @see WP_Query::get_posts()
		 *
		 * @param array $args An array of arguments used to retrieve the recent posts.
		 */
		$get_post_args = array(
			'posts_per_page'      	=> $number,
			'post_status'         	=> 'publish',
			'ignore_sticky_posts' 	=> true,
			'order'					=> $order,
			'tax_query' => array(
		        array(
		            'taxonomy' => 'post_format',
		            'field'    => 'slug',
		            'terms'    => array('post-format-quote'),
		            'operator' => 'NOT IN'
		        )
		    )
		);
		if ($orderby != 'post_view_count') {
			$get_post_args['orderby'] = $orderby;
		}
		else {
			$get_post_args['orderby'] = 'meta_value_num';
			$get_post_args['meta_key'] = 'forethemes_post_view_count';
		}

		if ($category_name != "all") {
			$get_post_args['category_name'] = $category_name;
		}

		//Get current theme name
		$current_theme = wp_get_theme();

		//Get all posts that fit the bill
		$r = new WP_Query( apply_filters( 'widget_posts_args', $get_post_args ) );

		if ($r->have_posts()) :
			?>
			<?php echo $args['before_widget'];

			//Risdan theme
			if ($current_theme == "Risdan") : ?>

				<div class="featured-posts owl-carousel">
					<?php while ( $r->have_posts() ) : $r->the_post(); ?>

						<!-- get post thumbnail url -->
						<?php $thumbnail = wp_get_attachment_image_src( get_post_thumbnail_id(), "700" );
						$thumbnail = "url('" . $thumbnail[0] . "')";?>

						<div class="featured-post" style="background-image:<?php echo $thumbnail;?>">
							<div class="featured-post-info">
								<div class="featured-post-title">
									<a href="<?php the_permalink(); ?>"><h2><?php get_the_title() ? the_title() : the_ID(); ?></h2></a>
								</div>
								<a href="<?php the_permalink(); ?>" class="continue-reading"><?php esc_html_e('Continue reading', 'forethemes');?></a>
							</div>
						</div>
					<?php endwhile; ?>
				</div><?php

			//Blaize
			elseif ($current_theme == "Blaize") : ?>

				<div class="featured-posts owl-carousel">
					<?php while ( $r->have_posts() ) : $r->the_post();

						//Get excerpt
						if ( empty( get_the_excerpt() ) ) 
                			$excerpt = wp_kses_post( wp_trim_words( get_the_content(), 40, ' ...' ) );
              			else 
                			$excerpt = wp_kses_post( wp_trim_words( get_the_excerpt(), 40, ' ...' ) );

						//Get post thumbnail url
						$thumbnail = wp_get_attachment_image_src( get_post_thumbnail_id(), "700" );
						$thumbnail = "url('" . $thumbnail[0] . "')";?>

						<div class="featured-post" style="background-image:<?php echo $thumbnail;?>">

							<div class="featured-post-info">
								<h2><a class="featured-post-title" href="<?php the_permalink(); ?>"><?php get_the_title() ? the_title() : the_ID(); ?></a></h2>
								<span class="featured-post-date"><?php echo get_the_date('F j');?></span>
							</div><!-- .featured-post-info -->

							<div class="featured-post-excerpt">
								<?php the_category(); ?>
								<p><?php echo $excerpt; ?></p>
							</div><!-- .featured-post-excerpt -->

						</div>

					<?php endwhile; ?>
				</div>
				<?php

			endif;

		endif;

		echo $args['after_widget']; ?>
		<?php
		// Reset the global $the_post as this query will have stomped on it
		wp_reset_postdata();
	}

	/**
	 * Handles updating the settings for the current Posts widget instance.
	 *
	 * @since 2.8.0
	 * @access public
	 *
	 * @param array $new_instance New settings for this instance as input by the user via
	 *                            WP_Widget::form().
	 * @param array $old_instance Old settings for this instance.
	 * @return array Updated settings to save.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['number'] 		= (int) $new_instance['number'];
		$instance['show_date'] 		= isset( $new_instance['show_date'] ) ? (bool) $new_instance['show_date'] 		: false;

		$instance['orderby'] 		= isset( $new_instance['orderby'] ) ? esc_attr( $new_instance['orderby'] ) 			: 'date';
		$instance['order']			= isset( $new_instance['order'] ) ? esc_attr( $new_instance['order'] ) 			: 'desc';
		$instance['category_name'] 	= isset( $new_instance['category_name'] ) ? esc_attr( $new_instance['category_name'] ) 	: 'all';
		
		return $instance;
	}

	/**
	 * Outputs the settings form for the Posts widget.
	 *
	 * @since 2.8.0
	 * @access public
	 *
	 * @param array $instance Current settings.
	 */
	public function form( $instance ) {
		$number    		= isset( $instance['number'] ) 			? absint( $instance['number'] ) 			: 5;
		$show_date 		= isset( $instance['show_date'] ) 		? (bool) $instance['show_date'] 			: false;

		$orderby 		= isset( $instance['orderby'] ) 		? esc_attr( $instance['orderby'] ) 			: 'date';
		$order 			= isset( $instance['order'] ) 			? esc_attr( $instance['order'] ) 			: 'desc';
		$category_name 	= isset( $instance['category_name'] ) 	? esc_attr( $instance['category_name'] ) 	: 'all';

?>
		<p><label for="<?php echo $this->get_field_id( 'number' ); ?>"><?php _e( 'Number of posts to show:', 'forethemes' ); ?></label>
		<input class="tiny-text" id="<?php echo $this->get_field_id( 'number' ); ?>" name="<?php echo $this->get_field_name( 'number' ); ?>" type="number" step="1" min="1" value="<?php echo $number; ?>" size="3" /></p>

		<p><input class="checkbox" type="checkbox"<?php checked( $show_date ); ?> id="<?php echo $this->get_field_id( 'show_date' ); ?>" name="<?php echo $this->get_field_name( 'show_date' ); ?>" />
		<label for="<?php echo $this->get_field_id( 'show_date' ); ?>"><?php _e( 'Display post date?', 'forethemes' ); ?></label></p>

		<p><label for="<?php echo $this->get_field_id( 'category_name' ); ?>"><?php _e( 'Get posts from category:', 'forethemes' ); ?></label>
			<select name="<?php echo $this->get_field_name( 'category_name' ); ?>" id="<?php echo $this->get_field_id( 'category_name' ); ?>">
				<option value="all" <?php if ($category_name == 'all') echo esc_attr('selected');?> >
				<?php _e('All Categories', 'forethemes'); ?></option>

				<?php
				$categories = get_categories( array('orderby' => 'name','order' => 'ASC') );
				foreach( $categories as $category ) {
					?><option value="<?php echo $category->slug ?>" 
					<?php if ($category_name == $category->slug) echo esc_attr('selected');?> >
					<?php echo $category->name ?></option><?php
				}
				?>
			</select>
		</p>

		<p><label for="<?php echo $this->get_field_id( 'orderby' ); ?>"><?php _e( 'Order by:', 'forethemes' ); ?></label>
			<select name="<?php echo $this->get_field_name( 'orderby' ); ?>" id="<?php echo $this->get_field_id( 'orderby' ); ?>">
				<option value="title" <?php if ($orderby == 'title') echo esc_attr('selected');?> >
					<?php _e('Title', 'forethemes');?></option>
				<option value="date" <?php if ($orderby == 'date') echo esc_attr('selected');?> >
					<?php _e('Publish date', 'forethemes');?></option>
				<option value="modified" <?php if ($orderby == 'modified') echo esc_attr('selected');?> >
					<?php _e('Modified date', 'forethemes');?></option>
				<option value="comment_count" <?php if ($orderby == 'comment_count') echo esc_attr('selected');?> >
					<?php _e('Comment Count', 'forethemes');?></option>
				<option value="post_view_count" <?php if ($orderby == 'post_view_count') echo esc_attr('selected');?> >
					<?php _e('Post View Count', 'forethemes');?></option>
			</select>
		</p>

		<p><label for="<?php echo $this->get_field_id( 'order' ); ?>"><?php _e( 'Order:', 'forethemes' ); ?></label>
			<select name="<?php echo $this->get_field_name( 'order' ); ?>" id="<?php echo $this->get_field_id( 'order' ); ?>">
				<option value="asc" <?php if ($order == 'asc') echo esc_attr('selected');?> >
				<?php _e('Ascending', 'forethemes');?></option>
				<option value="desc" <?php if ($order == 'desc') echo esc_attr('selected');?> >
				<?php _e('Descending', 'forethemes');?></option>
				<option value="rand" <?php if ($order == 'rand') echo esc_attr('selected');?> >
				<?php _e('Random', 'forethemes');?></option>
			</select>
		</p>
<?php
	}
}